import useLanguage from '@hooks/useLanguage'
import { IconAlertTriangle } from '@tabler/icons-solidjs'
import { Show, createSignal } from 'solid-js'
import Popup from '../Popup'

export default function ConfirmPopup(props) {
  const [openModal, setOpenModal] = createSignal(true)
  const { language } = useLanguage()

  const onConfirm = () => {
    props.onConfirm(props.deleteId)
    setOpenModal(false)
  }

  return (
    <Show when={openModal()}>
      <Popup
        icon={<IconAlertTriangle size={20} class="text-red-500" />}
        title={props.title}
        titleClass="text-md"
        openModal={openModal()}
        onModalClose={() => setOpenModal(false)}
        class="!w-4/12 !max-w-4xl"
      >
        <div class="modal-body">{props.children}</div>
        <div class="modal-action">
          <button
            type="submit"
            class="btn btn-primary btn-sm"
            onClick={onConfirm}
          >
            {language.ui.confirm}
          </button>
          <button
            type="button"
            class="btn btn-ghost btn-sm"
            onClick={() => setOpenModal(false)}
          >
            {language.ui.cancel}
          </button>
        </div>
      </Popup>
    </Show>
  )
}
