import { DOTS, usePagination } from '@hooks/usePagination'
import { For, Show, splitProps } from 'solid-js'

export default function Pagination(props) {
  const [localProps, onEvents] = splitProps(
    props,
    ['currentPage', 'totalCount', 'pageSize'],
    ['onPageChange'],
  )

  const paginationRange = usePagination(localProps)

  const onNext = () => {
    onEvents.onPageChange(localProps.currentPage() + 1)
  }

  const onPrevious = () => {
    onEvents.onPageChange(localProps.currentPage() - 1)
  }

  return (
    <Show when={localProps.currentPage !== 0 || paginationRange().length > 1}>
      <div class="pagination join">
        <button
          class="join-item btn btn-sm border border-gray-300"
          disabled={localProps.currentPage() === 1}
          onClick={onPrevious}
        >
          «
        </button>
        <For each={paginationRange()}>
          {(page) => {
            if (page === DOTS) {
              return (
                <button
                  class="join-item btn btn-sm hidden lg:block border !border-gray-300"
                  disabled
                >
                  ...
                </button>
              )
            }
            return (
              <button
                class="join-item btn btn-sm hidden lg:block border border-gray-300"
                classList={{
                  '!block btn-primary': page === localProps.currentPage(),
                }}
                onClick={[onEvents.onPageChange, page]}
              >
                {page}
              </button>
            )
          }}
        </For>
        <button
          class="join-item btn btn-sm border border-gray-300"
          disabled={
            localProps.currentPage() ===
            Math.ceil(localProps.totalCount() / localProps.pageSize())
          }
          onClick={onNext}
        >
          »
        </button>
      </div>
    </Show>
  )
}
